pub struct Request {
pub uri: Uri,
pub source: ResolvedInputSource,
pub element: Option<String>,
pub attribute: Option<String>,
pub span: Option<RawUriSpan>,
pub credentials: Option<BasicAuthCredentials>,
}Expand description
A checkable element extracted from a ResolvedInputSource,
containing a Uri and additional metadata associated with it.
Fields
uri: UriThe extracted Uniform Resource Identifier which can be checked with lychee
source: ResolvedInputSourceThe resource which contains the given URI
element: Option<String>How the URI is rendered inside a document
(for example img, a, pre, or code).
In case of plaintext input the field is None.
attribute: Option<String>What attribute (e.g. href) the URI is contained in
span: Option<RawUriSpan>Where the URI is located
credentials: Option<BasicAuthCredentials>Basic auth credentials
Implementations
Sourceimpl Request
impl Request
Sourcepub const fn new(uri: Uri, source: ResolvedInputSource) -> Self
pub const fn new(uri: Uri, source: ResolvedInputSource) -> Self
Instantiate a new Request object,
with optional fields set to None
Sourcepub fn with_element(self, element: String) -> Self
pub fn with_element(self, element: String) -> Self
Set Self::element
Sourcepub fn with_attribute(self, attribute: String) -> Self
pub fn with_attribute(self, attribute: String) -> Self
Set Self::attribute
Sourcepub const fn with_span(self, span: RawUriSpan) -> Self
pub const fn with_span(self, span: RawUriSpan) -> Self
Set Self::span
Sourcepub fn with_credentials(self, credentials: BasicAuthCredentials) -> Self
pub fn with_credentials(self, credentials: BasicAuthCredentials) -> Self